﻿using Infragistics.Web.Mvc;
using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using hieararchicalGridLoadOnDemand.Models;
using OpenQA.Selenium.Chrome;
using OpenQA.Selenium;
using System.Drawing;

namespace bindRemoteDataSource.Controllers
{
    public class HomeController : Controller
    {
        //
        // GET: /Home/

        public ActionResult Index()
        {
            GridModel productModel = GetProductModel();


            return View(productModel);
        }
        /* configures the parent layout */
        private GridModel GetProductModel()
        {
            GridModel gridModel = new GridModel();
            gridModel.ID = "grid1";
            gridModel.Width = "900px";
            gridModel.AutoGenerateColumns = false;
            gridModel.PrimaryKey = "ProductID";
            gridModel.Columns.Add(new GridColumn() { Key = "ProductID", HeaderText = "Main Product ID" });
            gridModel.Columns.Add(new GridColumn() { Key = "Name", HeaderText = "Main Layout Name", DataType = "string" });
            gridModel.Columns.Add(new GridColumn() { Key = "Date", HeaderText = "Main Date", DataType = "date", Format = "dateTime" });
            gridModel.AutoGenerateLayouts = false;
            gridModel.LoadOnDemand = true;
            gridModel.AutoCommit = true;
            gridModel.DataSource = GetProductData().AsQueryable();
            GridColumnLayoutModel childModel = GetProductInventoryModel();
            gridModel.ColumnLayouts.Add(childModel);
            GridFiltering filtering = new GridFiltering();
            GridUpdating updating = new GridUpdating();
            updating.EditMode = GridEditMode.Row;
            updating.AddClientEvent("editRowEnded", "editHandler");
            gridModel.Features.Add(filtering);
            gridModel.Features.Add(updating);

            return gridModel;
        }


        /* configures the child layout */


        private GridColumnLayoutModel GetProductInventoryModel()
        {
            GridColumnLayoutModel childModel = new GridColumnLayoutModel();
            childModel.Key = "ChildData";
            childModel.PrimaryKey = "ProductID";
            childModel.ForeignKey = "ParentProdID";
            childModel.Columns.Add(new GridColumn() { Key = "ProductID", HeaderText = "Child Product ID" });
            childModel.Columns.Add(new GridColumn() { Key = "Name", HeaderText = "Child Layout Name", DataType = "string" });
            childModel.Columns.Add(new GridColumn() { Key = "Date", HeaderText = "Child Date", DataType = "date", Format = "dateTime" });
            childModel.DataSourceUrl = Url.Action("BindProductInventory");
            childModel.ResponseDataKey = "Records";
            return childModel;
        }

        

        private List<Product> GetProductData()
        {
            List<Product> data = new List<Product>();
            for (int i = 0; i < 10; i++)
            {
                data.Add(new Product() { ProductID = i, Name = " Main Name " + i, Date = DateTime.Now });
            }
            return data;
        }

        private List<ChildProduct> GetChildData(int fk)
        {
            List<ChildProduct> data = new List<ChildProduct>();
            for (int i = 0; i < 5; i++)
            {
                data.Add(new ChildProduct() { ProductID = i, Name = "Child Name " + i, Date = DateTime.Now, ParentProdID = fk });
            }
            return data;
        }

        public JsonResult BindProductInventory(string path, string layout)
        {
            JsonResult r = new JsonResult();

            r.JsonRequestBehavior = JsonRequestBehavior.AllowGet;
            string id = path.Split(':')[1];
            ResponseObj resp = new ResponseObj() { Records = GetChildData(Convert.ToInt16(id)) };
            r.Data = resp;
            return r;
        }

    }
}
